@@ -118,6 +118,7 @@ TopologyRefiner::Unrefine() {
         delete _refinements[i];
     }
     _refinements.clear();
+    _maxLevel = 0;
 
     assembleFarLevels();
 }
@@ -731,6 +732,11 @@ namespace {
         }
         Level::VTag compVTag = Level::VTag::BitwiseOr(vTags, fVerts.size());
 
+        //  Incomplete faces (incomplete neighborhood) are unconditionally excluded:
+        if (compVTag._incomplete) {
+            return false;
+        }
+
         //  Select non-manifold features if specified, otherwise treat as inf-sharp:
         if (compVTag._nonManifold && featureMask.selectNonManifold) {
             return true;
